@@ -10,13 +10,20 @@ if not _isInited:
     init()
 
 
-def printColor(*values: Any, sep: str = " ", end: str = "\n", file: IO[str] = sys.stdout, flush: bool = False, colorList: list[Any] = []):
+def printColor(*values: Any, sep: str = " ", end: str = "\n", file: IO[str] = sys.stdout, flush: bool = False, colorList: list[Any] | None):
     '''color 数组参数 colorama.Fore / colorama.Back / colorama.Style 的常量'''
-    setPrintColor(*colorList)
+    if colorList:
+        setPrintColor(*colorList)
     print(*values, sep=sep, end=end, file=file, flush=flush)
     resetPrintColor()
 
 
+def getColorStr(value: str, colorList: list[Any] | None):
+    if colorList:
+        value = "".join(colorList) + value + Style.RESET_ALL
+    return value
+
+
 def setPrintColor(*colorList: Any):
     content = "".join(colorList)
     if content:
